@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2009 Niek Linnenbank
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -15,33 +15,12 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <errno.h>
-#include <string.h>
-#include <sys/stat.h>
+#include <StdioLog.h>
+#include "MakeNode.h"
 
 int main(int argc, char **argv)
 {
-    dev_t dev;
-
-    /* Verify command-line arguments. */
-    if (argc < 5)
-    {
-	printf("usage: %s FILE TYPE MAJOR MINOR\r\n",
-		argv[0]);
-	return EXIT_FAILURE;
-    }
-    /* Fill in major/minor numbers. */
-    dev.major = atoi(argv[3]);
-    dev.minor = atoi(argv[4]);
-
-    /* Attempt to create the file. */
-    if (mknod(argv[1], S_IFCHR, dev) < 0)
-    {
-	printf("%s: failed to create '%s': %s\r\n",
-		argv[0], argv[1], strerror(errno));
-	return EXIT_FAILURE;
-    }
-    return EXIT_SUCCESS;
+    StdioLog log;
+    MakeNode app(argc, argv);
+    return app.run();
 }
