@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2009 Niek Linnenbank
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -18,40 +18,41 @@
 #ifndef __SH_EXITCOMMAND
 #define __SH_EXITCOMMAND
 
-#include <Factory.h>
 #include <Types.h>
 #include "ShellCommand.h"
 
+/**
+ * @addtogroup bin
+ * @{
+ *
+ * @addtogroup sh
+ * @{
+ */
+
 /**
  * Exit the Shell.
  */
-class ExitCommand : public ShellCommand, public Factory<ExitCommand>
+class ExitCommand : public ShellCommand
 {
-    public:
-    
-	/**
-	 * Constructor function.
-	 */
-	ExitCommand() : ShellCommand("exit", 0)
-	{
-	}
+  public:
 
-	/**
-	 * Get the help string for this command.
-	 * @return Pointer to character string describing what the command does.
-	 */
-	const char * help()
-	{
-	    return "Exit from the shell";
-	}
-    
-	/**
-	 * Executes the command.
-	 * @param nparams Number of parameters given.
-	 * @param params Array of parameters.
-	 * @return Error code or zero on success.
-	 */
-	int execute(Size nparams, char **params);
+    /**
+     * Constructor function.
+     */
+    ExitCommand();
+
+    /**
+     * Executes the command.
+     * @param nparams Number of parameters given.
+     * @param params Array of parameters.
+     * @return Error code or zero on success.
+     */
+    virtual int execute(Size nparams, char **params);
 };
 
+/**
+ * @}
+ * @}
+ */
+
 #endif /* __SH_EXITCOMMAND */
