@@ -18,40 +18,49 @@
 #ifndef __SH_HELPCOMMAND
 #define __SH_HELPCOMMAND
 
-#include <Factory.h>
 #include <Types.h>
 #include "ShellCommand.h"
 
+class Shell;
+
+/**
+ * @addtogroup bin
+ * @{
+ *
+ * @addtogroup sh
+ * @{
+ */
+
 /**
  * Prints the help info for all known ShellCommands.
  */
-class HelpCommand : public ShellCommand, public Factory<HelpCommand>
+class HelpCommand : public ShellCommand
 {
-    public:
+  public:
 
-	/**
-	 * Constructor function.
-	 */
-	HelpCommand() : ShellCommand("help", 0)
-	{
-	}
+    /**
+     * Constructor.
+     */
+    HelpCommand(Shell *shell);
 
-	/**
-	 * Get the help string for this command.
-	 * @return Pointer to character string describing what the command does.
-	 */
-	const char * help()
-	{
-	    return "Print the help message";
-	}
-    
-	/**
-	 * Executes the command.
-	 * @param nparams Number of parameters given.
-	 * @param params Array of parameters.
-	 * @return Error code or zero on success.
-	 */
-	int execute(Size nparams, char **params);
+    /**
+     * Executes the command.
+     *
+     * @param nparams Number of parameters given.
+     * @param params Array of parameters.
+     * @return Error code or zero on success.
+     */
+    virtual int execute(Size nparams, char **params);
+
+  private:
+
+    /** Shell object */
+    Shell *m_shell;
 };
 
+/**
+ * @}
+ * @}
+ */
+
 #endif /* __SH_HELPCOMMAND */
