@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2009 Niek Linnenbank
- * 
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -15,37 +15,44 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <API/PrivExec.h>
-#include <FreeNOS/Init.h>
-#include <FreeNOS/Interrupt.h>
-#include <FreeNOS/Scheduler.h>
-#include <FreeNOS/CPU.h>
-#include <Error.h>
+#include <Log.h>
+#include "PrivExec.h"
 
-int PrivExecHandler(PrivOperation op)
+API::Result PrivExecHandler(PrivOperation op, Address addr)
 {
+    DEBUG("");
+
     switch (op)
     {
-	case Idle:
-	    
-	    scheduler->setIdle(scheduler->current());
-	    irq_enable();
-	    
-	    while (true)
-		idle();
-	
-	case Reboot:
-	    reboot();
-	    while (true) ;
-	    
-	case Shutdown:
-	    shutdown();
-	    return ESUCCESS;
+    case Idle: {
+        ProcessManager *procs = Kernel::instance->getProcessManager();
+        procs->setIdle(procs->current());
+#ifdef INTEL
+        irq_enable();
 
-	default:
-	    ;
+        while (true)
+            idle();
+#endif /* INTEL */
+        }
+        return API::Success;
+
+    case Reboot:
+        cpu_reboot();
+        while (true) ;
+
+    case Shutdown:
+        cpu_shutdown();
+        return API::Success;
+
+    case WriteConsole:
+        if (Log::instance)
+        {
+            (*Log::instance) << (char *)addr;
+        }
+        return API::Success;
+
+    default:
+        ;
     }
-    return EINVAL;
+    return API::InvalidArgument;
 }
-
-INITAPI(PRIVEXEC, PrivExecHandler)
