@@ -15,38 +15,44 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <Types.h>
+#include <FreeNOS/System.h>
 #include "BubbleAllocator.h"
 
-BubbleAllocator::BubbleAllocator()
-{
-    region(0, 0);
-}
-
 BubbleAllocator::BubbleAllocator(Address start, Size size)
+    : Allocator()
+    , m_start((u8 *) start)
+    , m_current((u8 *) start)
+    , m_size(size)
 {
-    region(start, size);
 }
 
-Address BubbleAllocator::allocate(Size *sz)
+Size BubbleAllocator::size() const
 {
-    /* Do we still have enough room? */
-    if (current + *sz < start + size)
+    return m_size;
+}
+
+Size BubbleAllocator::available() const
+{
+    return m_size - (m_current - m_start);
+}
+
+Allocator::Result BubbleAllocator::allocate(Size *sz, Address *addr, Size align)
+{
+    Size needed = aligned(*sz, MEMALIGN);
+
+    // Do we still have enough room?
+    if (m_current + needed < m_start + m_size)
     {
-	current += *sz;
-	return (Address) (current - *sz);
+        m_current += needed;
+        *addr = (Address) (m_current - needed);
+        return Success;
     }
-    /* No more memory available. */
-    return (Address) 0;
+    // No more memory available
+    return OutOfMemory;
 }
 
-void BubbleAllocator::release(Address addr)
+Allocator::Result BubbleAllocator::release(Address addr)
 {
-}
-
-void BubbleAllocator::region(Address addr, Size size)
-{
-    this->start   = (u8 *) addr;
-    this->current = (u8 *) addr;
-    this->size    = size;
+    // BubbleAllocator never releases memory
+    return InvalidAddress;
 }
