@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2009 Niek Linnenbank
- * 
+ * Copyright (C) 2015 Niek Linnenbank
+ *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -19,11 +19,15 @@
 #define __LIBALLOC_POOLALLOCATOR_H
 
 #include <Types.h>
+#include <Macros.h>
 #include "Allocator.h"
 
-/** 
- * @defgroup liballoc liballoc 
- * @{ 
+/**
+ * @addtogroup lib
+ * @{
+ *
+ * @addtogroup liballoc
+ * @{
  */
 
 /** Minimum power of two for a pool size. */
@@ -34,6 +38,7 @@
 
 /**
  * Allocate this many blocks per default for the given size.
+ *
  * @param size Size of each block.
  */
 #define POOL_MIN_COUNT(size) \
@@ -55,57 +60,59 @@ typedef struct MemoryPool
 {
     /**
      * Marks the appropriate bits in the free and used block bitmap.
+     *
      * @return Pointer to the next available block, if any.
      */
     Address allocate()
     {
-	Address *ptr;
-	Size num = count / sizeof(Address);
-	
-	/* At least one. */
-	if (!num) num++;
+        Address *ptr;
+        Size num = count / sizeof(Address);
 
-	/* Scan bitmap as fast as possible. */
-	for (Size i = 0; i < num; i++)
-	{
-	    /* Point to the correct offset. */
-	    ptr = (Address *) (&blocks) + i;
-	
-	    /* Any blocks free? */
-	    if (*ptr != (Address) ~ZERO)
-	    {
-		/* Find the first free bit. */
-		for (Size bit = 0; bit < sizeof(Address) * 8; bit++)
-		{
-		    if (!(*ptr & 1 << bit))
-		    {
-			*ptr |= (1 << bit);
-			free--;
-			return addr + (((i * sizeof(Address) * 8) + bit) * size);
-		    }
-		}
-	    }
-	}
-	/* Out of memory. */
-	return ZERO;
+        // At least one
+        if (!num) num++;
+
+        // Scan bitmap as fast as possible
+        for (Size i = 0; i < num; i++)
+        {
+            // Point to the correct offset
+            ptr = (Address *) (&blocks) + i;
+
+            // Any blocks free?
+            if (*ptr != (Address) ~ZERO)
+            {
+                // Find the first free bit
+                for (Size bit = 0; bit < sizeof(Address) * 8; bit++)
+                {
+                    if (!(*ptr & 1 << bit))
+                    {
+                        *ptr |= (1 << bit);
+                        free--;
+                        return addr + (((i * sizeof(Address) * 8) + bit) * size);
+                    }
+                }
+            }
+        }
+        // Out of memory
+        return ZERO;
     }
 
     /**
      * Unmarks the appropriate bit for the given address.
+     *
      * @param a Address to unmark.
      */
     void release(Address a)
     {
-	Size index = (a - addr) / size / 8;
-	Size bit   = (a - addr) / size % 8;
-	
-	free++;
-	blocks[index] &= ~(1 << bit);
+        Size index = (a - addr) / size / 8;
+        Size bit   = (a - addr) / size % 8;
+
+        free++;
+        blocks[index] &= ~(1 << bit);
     }
 
     /** Points to the next pool of this size (if any). */
     MemoryPool *next;
-    
+
     /** Memory address allocated to this pool. */
     Address addr;
 
@@ -114,10 +121,10 @@ typedef struct MemoryPool
 
     /** Number of blocks in the pool. */
     Size count;
-    
+
     /** Free blocks left. */
     Size free;
-    
+
     /** Bitmap which represents free and used blocks. */
     u8 blocks[];
 }
@@ -125,48 +132,77 @@ MemoryPool;
 
 /**
  * Memory allocator which uses pools.
+ *
  * Allocates memory from pools the size of a power of two.
  * Each pool is pre-allocated and has a bitmap representing free blocks.
  */
 class PoolAllocator : public Allocator
 {
-    public:
+  public:
 
-	/**
-	 * Empty constructor.
-	 */
-	PoolAllocator();
+    /**
+     * Constructor
+     */
+    PoolAllocator();
 
-        /** 
-	 * Allocate a block of memory. 
-	 * @param size Amount of memory in bytes to allocate on input. 
-	 *             On output, the amount of memory in bytes actually allocated. 
-	 * @return New memory block on success and ZERO on failure. 
-	 */
-	Address allocate(Size *size);
+    /**
+     * Get memory size.
+     *
+     * @return Size of memory owned by the Allocator.
+     */
+    virtual Size size() const;
 
-	/**
-         * Free a block of memory. 
-	 * @param addr Points to memory previously returned by allocate(). 
-	 * @see allocate 
-	 */
-	void release(Address addr);
+    /**
+     * Get memory available.
+     *
+     * @return Size of memory available by the Allocator.
+     */
+    virtual Size available() const;
 
-    private:
+    /**
+     * Allocate memory.
+     *
+     * @param size Amount of memory in bytes to allocate on input.
+     *             On output, the amount of memory in bytes actually allocated.
+     * @param addr Output parameter which contains the address
+     *             allocated on success.
+     * @param align Alignment of the required memory or use ZERO for default.
+     *
+     * @return Result value.
+     */
+    virtual Result allocate(Size *size, Address *addr, Size align = ZERO);
 
-	/**
-	 * Creates a new MemoryPool instance.
-	 * @param index Index in the pools array.
-	 * @param cnt Allocate for this many of blocks from our parent.
-	 * @return Pointer to a MemoryPool object on success, ZERO on failure.
-	 */
-        MemoryPool * newPool(Size index, Size cnt);
+    /**
+     * Release memory.
+     *
+     * @param addr Points to memory previously returned by allocate().
+     *
+     * @return Result value.
+     *
+     * @see allocate
+     */
+    virtual Result release(Address addr);
 
-	/** Array of memory pools. Index represents the power of two. */
-	MemoryPool *pools[POOL_MAX_POWER];
+  private:
+
+    /**
+     * Creates a new MemoryPool instance.
+     *
+     * @param index Index in the pools array.
+     * @param cnt Allocate for this many of blocks from our parent.
+     *
+     * @return Pointer to a MemoryPool object on success, ZERO on failure.
+     */
+    MemoryPool * newPool(Size index, Size cnt);
+
+  private:
+
+    /** Array of memory pools. Index represents the power of two. */
+    MemoryPool *m_pools[POOL_MAX_POWER];
 };
 
 /**
+ * @}
  * @}
  */
 
